@@ -67,6 +67,8 @@ class R3sponse(object):
 		save=False,
 		# return as a django JsonResponse.
 		django=False,
+		# raise error for developer traceback.
+		traceback=ERROR_TRACEBACK,
 	):
 		response = self.default_response({
 			"success":False,
@@ -74,6 +76,8 @@ class R3sponse(object):
 			"error":error,
 		})
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
+		if traceback:
+			raise ValueError(response["error"])
 		if django: 
 			try:
 				response = JsonResponse(response.dict(), safe=False)
@@ -247,7 +251,7 @@ class R3sponse(object):
 			return response
 		
 		# check file size.
-		size = FilePath(self.log_file).size(mode="mb", type="integer")
+		size = FilePath(self.log_file).size(mode="mb", format="integer")
 		if size >= 100: self.reset_logs()
 
 		# return response.
@@ -342,8 +346,10 @@ class ResponseObject(object):
 
 		# clean message & error.
 		try:
+			if self.message in ["None", "null", "", "nan"]: self.message = None
 			if self.message != None:
 				self.message = String(self.message).capitalized_word()
+			if self.error in ["None", "null", "", "nan"]: self.error = None
 			if self.error != None:
 				self.error = String(self.error).capitalized_word()
 			while True:
